@@ -661,7 +661,24 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.progressioncombo, 
 			QtCore.SIGNAL("activated(int)"),
 			lambda x: self.add_progression())
-	
+		self.connect(self.ui.bpmslide,
+			QtCore.SIGNAL("sliderMoved(int)"),
+			lambda x: self.ui.bpm.setValue(x * 10))
+		self.connect(self.ui.bpm,
+			QtCore.SIGNAL("valueChanged(int)"),
+			lambda x: self.ui.bpmslide.setValue(x / 10))
+		self.connect(self.ui.loopslide,
+			QtCore.SIGNAL("sliderMoved(int)"),
+			lambda x: self.ui.loop.setValue(x * 10))
+		self.connect(self.ui.loop,
+			QtCore.SIGNAL("valueChanged(int)"),
+			lambda x: self.ui.loopslide.setValue(x / 10))
+		self.connect(self.ui.wildslide,
+			QtCore.SIGNAL("sliderMoved(int)"),
+			lambda x: self.ui.wildness.setValue(x / 10.0))
+		self.connect(self.ui.wildness,
+			QtCore.SIGNAL("valueChanged(double)"),
+			lambda x: self.ui.wildslide.setValue(int(x * 10)))
 
 	def set_defaults(self):
 
@@ -681,6 +698,11 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.ui.duration.setValue(1)
 		self.ui.loop.setValue(1)
 
+		# Slides
+		self.ui.bpmslide.setValue(12)
+		self.ui.loopslide.setValue(1)
+		self.ui.wildslide.setValue(10)
+
 		# Lists
 		self.ui.progressions.clear()
 		self.ui.blocks.clear()
